@@ -7,4 +7,6 @@ class AssetCategory(Enum):
 
 
 def get_full_path(category: AssetCategory, name: str):
+    if not name:
+        raise ValueError("file name is None.")
     return os.path.join(os.path.dirname(os.path.abspath(__file__)), category.value, name)
\ No newline at end of file
